@@ -5,7 +5,6 @@ rate limiting strategies
 from abc import ABCMeta, abstractmethod
 import weakref
 import six
-import time
 
 
 @six.add_metaclass(ABCMeta)
@@ -25,6 +24,19 @@ class RateLimiter(object):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def test(self, item, *identifiers):
+        """
+        checks  the rate limit and returns True if it is not
+        currently exceeded.
+
+        :param item: a :class:`RateLimitItem` instance
+        :param identifiers: variable list of strings to uniquely identify the
+         limit
+        :return: True/False
+        """
+        raise NotImplementedError
+
     @abstractmethod
     def get_window_stats(self, item, *identifiers):
         """
@@ -37,6 +49,8 @@ class RateLimiter(object):
         """
         raise NotImplementedError
 
+    def clear(self, item, *identifiers):
+        return self.storage().clear(item.key_for(*identifiers))
 
 
 class MovingWindowRateLimiter(RateLimiter):
@@ -45,8 +59,13 @@ class MovingWindowRateLimiter(RateLimiter):
     """
 
     def __init__(self, storage):
-        if not (hasattr(storage, "acquire_entry") or hasattr(storage, "get_moving_window")):
-            raise NotImplementedError("MovingWindowRateLimiting is not implemented for storage of type %s" % storage.__class__)
+        if not (
+            hasattr(storage, "acquire_entry") or hasattr(storage, "get_moving_window")
+        ):
+            raise NotImplementedError(
+                "MovingWindowRateLimiting is not implemented for storage "
+                "of type %s" % storage.__class__
+            )
         super(MovingWindowRateLimiter, self).__init__(storage)
 
     def hit(self, item, *identifiers):
@@ -58,7 +77,28 @@ class MovingWindowRateLimiter(RateLimiter):
          limit
         :return: True/False
         """
-        return self.storage().acquire_entry(item.key_for(*identifiers), item.amount, item.get_expiry())
+        return self.storage().acquire_entry(
+            item.key_for(*identifiers), item.amount, item.get_expiry()
+        )
+
+    def test(self, item, *identifiers):
+        """
+        checks  the rate limit and returns True if it is not
+        currently exceeded.
+
+        :param item: a :class:`RateLimitItem` instance
+        :param identifiers: variable list of strings to uniquely identify the
+         limit
+        :return: True/False
+        """
+        return (
+            self.storage().get_moving_window(
+                item.key_for(*identifiers),
+                item.amount,
+                item.get_expiry(),
+            )[1]
+            < item.amount
+        )
 
     def get_window_stats(self, item, *identifiers):
         """
@@ -70,8 +110,8 @@ class MovingWindowRateLimiter(RateLimiter):
         :return: tuple (reset time (int), remaining (int))
         """
         window_start, window_items = self.storage().get_moving_window(
-                item.key_for(*identifiers), item.amount, item.get_expiry()
-            )
+            item.key_for(*identifiers), item.amount, item.get_expiry()
+        )
         reset = window_start + item.get_expiry()
         return (reset, item.amount - window_items)
 
@@ -80,6 +120,7 @@ class FixedWindowRateLimiter(RateLimiter):
     """
     Reference: :ref:`fixed-window`
     """
+
     def hit(self, item, *identifiers):
         """
         creates a hit on the rate limit and returns True if successful.
@@ -94,6 +135,18 @@ class FixedWindowRateLimiter(RateLimiter):
             <= item.amount
         )
 
+    def test(self, item, *identifiers):
+        """
+        checks  the rate limit and returns True if it is not
+        currently exceeded.
+
+        :param item: a :class:`RateLimitItem` instance
+        :param identifiers: variable list of strings to uniquely identify the
+         limit
+        :return: True/False
+        """
+        return self.storage().get(item.key_for(*identifiers)) < item.amount
+
     def get_window_stats(self, item, *identifiers):
         """
         returns the number of requests remaining and reset of this limit.
@@ -107,6 +160,7 @@ class FixedWindowRateLimiter(RateLimiter):
         reset = self.storage().get_expiry(item.key_for(*identifiers))
         return (reset, remaining)
 
+
 class FixedWindowElasticExpiryRateLimiter(FixedWindowRateLimiter):
     """
     Reference: :ref:`fixed-window-elastic`
@@ -126,8 +180,9 @@ class FixedWindowElasticExpiryRateLimiter(FixedWindowRateLimiter):
             <= item.amount
         )
 
+
 STRATEGIES = {
     "fixed-window": FixedWindowRateLimiter,
     "fixed-window-elastic-expiry": FixedWindowElasticExpiryRateLimiter,
-    "moving-window": MovingWindowRateLimiter
-}
\ No newline at end of file
+    "moving-window": MovingWindowRateLimiter,
+}
