@@ -4,13 +4,26 @@
 import re
 import sys
 
+import six
+
 from .limits import GRANULARITIES
 
-
-EXPR = re.compile(
-    r"\s*([0-9]+)\s*(/|\s*per\s*)\s*([0-9]+)*\s*(hour|minute|second|day|month|year)[s]*",
-    re.IGNORECASE
+SEPARATORS = re.compile(r"[,;|]{1}")
+SINGLE_EXPR = re.compile(
+    r"""
+    \s*([0-9]+)
+    \s*(/|\s*per\s*)
+    \s*([0-9]+)
+    *\s*(hour|minute|second|day|month|year)s?\s*""",
+    re.IGNORECASE | re.VERBOSE,
 )
+EXPR = re.compile(
+    r"^{SINGLE}(:?{SEPARATORS}{SINGLE})*$".format(
+        SINGLE=SINGLE_EXPR.pattern, SEPARATORS=SEPARATORS.pattern
+    ),
+    re.IGNORECASE | re.VERBOSE,
+)
+
 
 def get_dependency(dep):
     """
@@ -20,7 +33,7 @@ def get_dependency(dep):
     try:
         __import__(dep)
         return sys.modules[dep]
-    except ImportError: # pragma: no cover
+    except ImportError:  # pragma: no cover
         return None
 
 
@@ -34,17 +47,20 @@ def parse_many(limit_string):
     :return: a list of :class:`RateLimitItem` instances.
 
     """
-    if not EXPR.match(limit_string):
+    if not (isinstance(limit_string, six.string_types) and EXPR.match(limit_string)):
         raise ValueError("couldn't parse rate limit string '%s'" % limit_string)
     limits = []
-    for amount, _, multiples, granularity_string in  EXPR.findall(limit_string):
+    for limit in SEPARATORS.split(limit_string):
+        amount, _, multiples, granularity_string = SINGLE_EXPR.match(limit).groups()
         granularity = granularity_from_string(granularity_string)
         limits.append(granularity(amount, multiples))
     return limits
 
+
 def parse(limit_string):
     """
-    parses a single rate limit in string notation (e.g. '1/second' or '1 per second'
+    parses a single rate limit in string notation
+    (e.g. '1/second' or '1 per second'
 
     :param string limit_string: rate limit string using :ref:`ratelimit-string`
     :raise ValueError: if the string notation is invalid.
@@ -65,4 +81,3 @@ def granularity_from_string(granularity_string):
         if granularity.check_granularity_string(granularity_string):
             return granularity
     raise ValueError("no granularity matched for %s" % granularity_string)
-
